@@ -1,5 +1,5 @@
-from .main import *
+from .__main__ import *
 
-__version__ = '1.0.0'
+__version__ = '1.0.1'
 __author__ = 'MrPowerUp - www.github.com/MrPowerUp82'
 __license__ = 'MIT'
\ No newline at end of file
